pub struct FunctionTransformer<F: Float> { /* private fields */ }Expand description
A transformer that applies an arbitrary function to the data.
Implements FitTransform so it can be used directly in a Pipeline.
The fit step is a no-op — only the transform function is called.
Example
ⓘ
use anofox_ml_core::{Pipeline, FunctionTransformer};
let log_transform = FunctionTransformer::new(|x: &Array2<f64>| {
Ok(x.mapv(|v| v.ln()))
});
let pipeline = Pipeline::new()
.push_transformer("log", log_transform);Implementations